@@ -22,49 +22,15 @@ have no way of getting an advance look at what the tool thinks should go
 into your distribution; you only see what's in the distribution after it
 is built.
 
-Using setuputils in this mode is simple: for each section of setup.cfg,
-you put options that you want to specify in advance rather than have
-setuputils auto-discover in an .in file in the root of your source tree.
-For example, you would put metadata in the file metadata.in, options in
-the file options.in, etc. You would not include anything that you want
-setuputils to auto-discover, so, for example, if you want setuputils to
-auto-discover your packages, you would not include "packages" in your
-options.in file at all (whereas with setuptools you would include
-"packages = find:" in your setup.cfg).
-
-(Note that, in addition to the standard setuptools keywords, there are
-a few extra keywords that are used by setuputils itself, either to allow
-simpler inputs that then get expanded into standard format, as with the
-"dev_status" keyword, or to allow you to pass options to setuputils to
-control its behavior, as with the "autodiscover" keyword. These keywords
-are described further in the appropriate function docstrings below.)
-
-Once you have created your .in files, then you simply execute
-
-    python3 -m setuputils
-
-in the root of your source tree. This will build the setup.cfg file for
-you. You can then look at it to make sure it is correct before using a
-build backend to build your distribution.
-
-With this mode, if you are using a PEP 517 compliant build backend, you
-do not need a setup.py script at all. (Setuptools qualifies as such a
-backend as long as you include a pyproject.toml file and specify
-setuptools in it, as described in the Python packaging documentation.)
-If you do have a setup.py script, all it would need to contain is
-an import of ``setuptools`` and call to ``setuptools.setup()`` with no
-arguments (since all of the information needed is in setup.cfg). Note,
-however, that if you have a setup.py script that was used with previous
-versions of setuputils, you do not have to transition it to the new
-format using .in files all at once. Setuputils will read any global
-variables that are defined in your setup.py, as you would have done in
-previous setuputils versions, and include them in what it outputs to
-setup.cfg after processing them just as it would have in previous
-versions, so you can transition things incrementally if that works
-better for your project. (However, you should remove any calls to
-setup_vars in your setup.py script, leaving only the call to
-``setuptools.setup()`` with no arguments, since all the information
-it needs will be in setup.cfg.)
+Using setuputils in this mode is described in the README file that comes
+with the setuputils distribution. This mode supports both being run as
+a stand-alone tool to build setup.cfg prior to doing an sdist or wheel
+build, and being run as a PEP 517 build backend that builds setup.cfg
+before each build to ensure consistency with the current state of your
+source tree. This mode also supports reading global variables from a
+setup.py script if that is present (see further comments below); but if
+setup.py is present, setuputils cannot be used as a build backend, it
+can only be used to generate setup.cfg prior to doing a build.
 
 (Note that extension modules are currently not supported in setup.cfg,
 so you cannot use setuputils in setup.cfg mode if your distribution
@@ -1043,10 +1009,14 @@ def read_in_lines(lines,
     return in_vars
 
 
+def in_filename(section):
+    return "{}.in".format(section)
+
+
 def read_in_files():
     varmap = {}
     for section, _ in setup_cfg_sections:
-        filename = "{}.in".format(section)
+        filename = in_filename(section)
         if os.path.isfile(filename):
             with open(filename, 'r') as f:
                 lines = f.readlines()
@@ -1102,6 +1072,16 @@ def write_out_file(cfg_vars, sorted_output=True):
         f.writelines(lines)
 
 
+def fix_egg_base(cfg_vars, drive_letter="C"):
+    # Special-case this so path separators are correct
+    egg_base = cfg_vars.get('egg_base')
+    if egg_base and (os.sep != '/'):
+        egg_base = egg_base.replace('/', os.sep)
+        if egg_base.startswith(os.sep) and (os.name == 'nt'):
+            egg_base = "{}:{}".format(drive_letter, egg_base)
+        cfg_vars['egg_base'] = egg_base
+
+
 def write_setup_cfg(autodiscover=True, sorted_output=True):
     if os.path.isfile('setup.py'):
         varmap = read_setup_py()
@@ -1112,6 +1092,7 @@ def write_setup_cfg(autodiscover=True, sorted_output=True):
     autodiscover = varmap.get('autodiscover', autodiscover)
     sorted_output = varmap.get('sorted_output', sorted_output)
     cfg_vars = setup_vars(varmap, autodiscover=autodiscover, force_manifest_in=None)
+    fix_egg_base(cfg_vars)
     forbidden_keys = [k for k in cfg_vars if k in no_setup_cfg_keys]
     if forbidden_keys:
         raise RuntimeError("Keys {} are not supported in setup.cfg.".format(", ".join(forbidden_keys)))
